Utilities and compatibility
***************************

.. automodule:: genno.compat.dask
   :members:

.. automodule:: genno.compat.graphviz
   :members:

.. automodule:: genno.compat.pandas
   :members:

.. automodule:: genno.core.describe
   :members:

.. automodule:: genno.core.graph
   :members:

.. automodule:: genno.core.key
   :members: KeyLike, iter_keys, single_key

.. automodule:: genno.core.operator
   :members:
   :exclude-members: Operator

.. automodule:: genno.types
   :members:

.. automodule:: genno.util
   :members:
